pub struct Wwdt { /* private fields */ }Expand description
Windowed Watchdog Timer (WWDT)
Implementations
Sourceimpl Wwdt
impl Wwdt
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn mod_(self) -> Reg<Mod, RW>
pub const fn mod_(self) -> Reg<Mod, RW>
Watchdog mode register. This register contains the basic mode and status of the Watchdog Timer.
Sourcepub const fn tc(self) -> Reg<Tc, RW>
pub const fn tc(self) -> Reg<Tc, RW>
Watchdog timer constant register. This 24-bit register determines the time-out value.
Sourcepub const fn feed(self) -> Reg<Feed, W>
pub const fn feed(self) -> Reg<Feed, W>
Watchdog feed sequence register. Writing 0xAA followed by 0x55 to this register reloads the Watchdog timer with the value contained in TC.